@@ -100,15 +100,31 @@ def test_control_client_create_environment_with_multiple_nodes_runs_environment(
 
 def test_control_client_clone_environment_runs_cloned_environment(
         control_client: ControlClient,
-        created_environment: EnvInfo):
+        created_environment: EnvInfo,
+        cloned_environment: EnvInfo):
     # Arrange
-    created_env_name = created_environment.env_name()
-    cloned_env_name = created_env_name + "-clone"
 
     # Act
-    cloned_environment = control_client.clone_env(
-        created_env_name, cloned_env_name)
 
     # Assert
     assert cloned_environment.is_running()
     assert len(created_environment.nodes()) == len(cloned_environment.nodes())
+
+
+def test_control_client_start_stopped_environment(
+        control_client: ControlClient,
+        created_environment: EnvInfo
+):
+    # Arrange
+    assert created_environment.is_running()
+    env_name = created_environment.env_name()
+    control_client.stop_env(env_name)
+    env_info = control_client.get_env_info(env_name)
+    assert not env_info.is_running()
+
+    # Act
+    control_client.start_env(env_name)
+
+    # Assert
+    env_info = control_client.get_env_info(env_name)
+    assert env_info.is_running()
